==> 0.0.1.tar.gz: lib/model/paymentstatus/SDKPaymentStatusResponse.dart <==
class SDKPaymentStatusResponse {
  MFPaymentStatusResponse data;

  SDKPaymentStatusResponse({this.data});

  SDKPaymentStatusResponse.fromJson(Map<String, dynamic> json) {
    data = json['Data'] != null ? new MFPaymentStatusResponse.fromJson(json['Data']) : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if (this.data != null) {
      data['Data'] = this.data.toJson();
    }
    return data;
  }
}

class MFPaymentStatusResponse {
  int invoiceId;
  String invoiceStatus;
  String invoiceReference;
  String customerReference;
  String createdDate;
  String expiryDate;
  double invoiceValue;
  String comments;
  String customerName;
  String customerMobile;
  String customerEmail;
  String userDefinedField;
  String invoiceDisplayValue;
  List<InvoiceItems> invoiceItems;
  List<InvoiceTransactions> invoiceTransactions;

  MFPaymentStatusResponse(
      {this.invoiceId,
        this.invoiceStatus,
        this.invoiceReference,
        this.customerReference,
        this.createdDate,
        this.expiryDate,
        this.invoiceValue,
        this.comments,
        this.customerName,
        this.customerMobile,
        this.customerEmail,
        this.userDefinedField,
        this.invoiceDisplayValue,
        this.invoiceItems,
        this.invoiceTransactions});

  MFPaymentStatusResponse.fromJson(Map<String, dynamic> json) {
    invoiceId = json['InvoiceId'];
    invoiceStatus = json['InvoiceStatus'];
    invoiceReference = json['InvoiceReference'];
    customerReference = json['CustomerReference'];
    createdDate = json['CreatedDate'];
    expiryDate = json['ExpiryDate'];
    invoiceValue = json['InvoiceValue'];
    comments = json['Comments'];
    customerName = json['CustomerName'];
    customerMobile = json['CustomerMobile'];
    customerEmail = json['CustomerEmail'];
    userDefinedField = json['UserDefinedField'];
    invoiceDisplayValue = json['InvoiceDisplayValue'];
    if (json['InvoiceItems'] != null) {
      invoiceItems = new List<InvoiceItems>();
      json['InvoiceItems'].forEach((v) {
        invoiceItems.add(new InvoiceItems.fromJson(v));
      });
    }
    if (json['InvoiceTransactions'] != null) {
      invoiceTransactions = new List<InvoiceTransactions>();
      json['InvoiceTransactions'].forEach((v) {
        invoiceTransactions.add(new InvoiceTransactions.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['InvoiceId'] = this.invoiceId;
    data['InvoiceStatus'] = this.invoiceStatus;
    data['InvoiceReference'] = this.invoiceReference;
    data['CustomerReference'] = this.customerReference;
    data['CreatedDate'] = this.createdDate;
    data['ExpiryDate'] = this.expiryDate;
    data['InvoiceValue'] = this.invoiceValue;
    data['Comments'] = this.comments;
    data['CustomerName'] = this.customerName;
    data['CustomerMobile'] = this.customerMobile;
    data['CustomerEmail'] = this.customerEmail;
    data['UserDefinedField'] = this.userDefinedField;
    data['InvoiceDisplayValue'] = this.invoiceDisplayValue;
    if (this.invoiceItems != null) {
      data['InvoiceItems'] = this.invoiceItems.map((v) => v.toJson()).toList();
    }
    if (this.invoiceTransactions != null) {
      data['InvoiceTransactions'] =
          this.invoiceTransactions.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class InvoiceItems {
  String itemName;
  int quantity;
  double unitPrice;

  InvoiceItems({this.itemName, this.quantity, this.unitPrice});

  InvoiceItems.fromJson(Map<String, dynamic> json) {
    itemName = json['ItemName'];
    quantity = json['Quantity'];
    unitPrice = json['UnitPrice'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['ItemName'] = this.itemName;
    data['Quantity'] = this.quantity;
    data['UnitPrice'] = this.unitPrice;
    return data;
  }
}

class InvoiceTransactions {
  String transactionDate;
  String paymentGateway;
  String referenceId;
  String trackId;
  String transactionId;
  String paymentId;
  String authorizationId;
  String transactionStatus;
  String transationValue;
  String customerServiceCharge;
  String dueValue;
  String paidCurrency;
  String paidCurrencyValue;
  String currency;
  String error;
  String cardNumber;

  InvoiceTransactions(
      {this.transactionDate,
        this.paymentGateway,
        this.referenceId,
        this.trackId,
        this.transactionId,
        this.paymentId,
        this.authorizationId,
        this.transactionStatus,
        this.transationValue,
        this.customerServiceCharge,
        this.dueValue,
        this.paidCurrency,
        this.paidCurrencyValue,
        this.currency,
        this.error,
        this.cardNumber});

  InvoiceTransactions.fromJson(Map<String, dynamic> json) {
    transactionDate = json['TransactionDate'];
    paymentGateway = json['PaymentGateway'];
    referenceId = json['ReferenceId'];
    trackId = json['TrackId'];
    transactionId = json['TransactionId'];
    paymentId = json['PaymentId'];
    authorizationId = json['AuthorizationId'];
    transactionStatus = json['TransactionStatus'];
    transationValue = json['TransationValue'];
    customerServiceCharge = json['CustomerServiceCharge'];
    dueValue = json['DueValue'];
    paidCurrency = json['PaidCurrency'];
    paidCurrencyValue = json['PaidCurrencyValue'];
    currency = json['Currency'];
    error = json['Error'];
    cardNumber = json['CardNumber'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['TransactionDate'] = this.transactionDate;
    data['PaymentGateway'] = this.paymentGateway;
    data['ReferenceId'] = this.referenceId;
    data['TrackId'] = this.trackId;
    data['TransactionId'] = this.transactionId;
    data['PaymentId'] = this.paymentId;
    data['AuthorizationId'] = this.authorizationId;
    data['TransactionStatus'] = this.transactionStatus;
    data['TransationValue'] = this.transationValue;
    data['CustomerServiceCharge'] = this.customerServiceCharge;
    data['DueValue'] = this.dueValue;
    data['PaidCurrency'] = this.paidCurrency;
    data['PaidCurrencyValue'] = this.paidCurrencyValue;
    data['Currency'] = this.currency;
    data['Error'] = this.error;
    data['CardNumber'] = this.cardNumber;
    return data;
  }
}

==> 0.1.2.tar.gz: lib/model/paymentstatus/SDKPaymentStatusResponse.dart <==
class SDKPaymentStatusResponse {
  MFPaymentStatusResponse data;

  SDKPaymentStatusResponse({this.data});

  SDKPaymentStatusResponse.fromJson(Map<String, dynamic> json) {
    data = json['Data'] != null ? new MFPaymentStatusResponse.fromJson(json['Data']) : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if (this.data != null) {
      data['Data'] = this.data.toJson();
    }
    return data;
  }
}

class MFPaymentStatusResponse {
  int invoiceId;
  String invoiceStatus;
  String invoiceReference;
  String customerReference;
  String createdDate;
  String expiryDate;
  double invoiceValue;
  String comments;
  String customerName;
  String customerMobile;
  String customerEmail;
  String userDefinedField;
  String invoiceDisplayValue;
  List<Item> invoiceItems;
  List<InvoiceTransactions> invoiceTransactions;

  MFPaymentStatusResponse(
      {this.invoiceId,
        this.invoiceStatus,
        this.invoiceReference,
        this.customerReference,
        this.createdDate,
        this.expiryDate,
        this.invoiceValue,
        this.comments,
        this.customerName,
        this.customerMobile,
        this.customerEmail,
        this.userDefinedField,
        this.invoiceDisplayValue,
        this.invoiceItems,
        this.invoiceTransactions});

  MFPaymentStatusResponse.fromJson(Map<String, dynamic> json) {
    invoiceId = json['InvoiceId'];
    invoiceStatus = json['InvoiceStatus'];
    invoiceReference = json['InvoiceReference'];
    customerReference = json['CustomerReference'];
    createdDate = json['CreatedDate'];
    expiryDate = json['ExpiryDate'];
    invoiceValue = json['InvoiceValue'];
    comments = json['Comments'];
    customerName = json['CustomerName'];
    customerMobile = json['CustomerMobile'];
    customerEmail = json['CustomerEmail'];
    userDefinedField = json['UserDefinedField'];
    invoiceDisplayValue = json['InvoiceDisplayValue'];
    if (json['InvoiceItems'] != null) {
      invoiceItems = new List<Item>();
      json['InvoiceItems'].forEach((v) {
        invoiceItems.add(new Item.fromJson(v));
      });
    }
    if (json['InvoiceTransactions'] != null) {
      invoiceTransactions = new List<InvoiceTransactions>();
      json['InvoiceTransactions'].forEach((v) {
        invoiceTransactions.add(new InvoiceTransactions.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['InvoiceId'] = this.invoiceId;
    data['InvoiceStatus'] = this.invoiceStatus;
    data['InvoiceReference'] = this.invoiceReference;
    data['CustomerReference'] = this.customerReference;
    data['CreatedDate'] = this.createdDate;
    data['ExpiryDate'] = this.expiryDate;
    data['InvoiceValue'] = this.invoiceValue;
    data['Comments'] = this.comments;
    data['CustomerName'] = this.customerName;
    data['CustomerMobile'] = this.customerMobile;
    data['CustomerEmail'] = this.customerEmail;
    data['UserDefinedField'] = this.userDefinedField;
    data['InvoiceDisplayValue'] = this.invoiceDisplayValue;
    if (this.invoiceItems != null) {
      data['InvoiceItems'] = this.invoiceItems.map((v) => v.toJson()).toList();
    }
    if (this.invoiceTransactions != null) {
      data['InvoiceTransactions'] =
          this.invoiceTransactions.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class Item {
  String itemName;
  int quantity;
  double unitPrice;

  Item({this.itemName, this.quantity, this.unitPrice});

  Item.fromJson(Map<String, dynamic> json) {
    itemName = json['ItemName'];
    quantity = json['Quantity'];
    unitPrice = json['UnitPrice'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['ItemName'] = this.itemName;
    data['Quantity'] = this.quantity;
    data['UnitPrice'] = this.unitPrice;
    return data;
  }
}

class InvoiceTransactions {
  String transactionDate;
  String paymentGateway;
  String referenceId;
  String trackId;
  String transactionId;
  String paymentId;
  String authorizationId;
  String transactionStatus;
  String transationValue;
  String customerServiceCharge;
  String dueValue;
  String paidCurrency;
  String paidCurrencyValue;
  String currency;
  String error;
  String cardNumber;

  InvoiceTransactions(
      {this.transactionDate,
        this.paymentGateway,
        this.referenceId,
        this.trackId,
        this.transactionId,
        this.paymentId,
        this.authorizationId,
        this.transactionStatus,
        this.transationValue,
        this.customerServiceCharge,
        this.dueValue,
        this.paidCurrency,
        this.paidCurrencyValue,
        this.currency,
        this.error,
        this.cardNumber});

  InvoiceTransactions.fromJson(Map<String, dynamic> json) {
    transactionDate = json['TransactionDate'];
    paymentGateway = json['PaymentGateway'];
    referenceId = json['ReferenceId'];
    trackId = json['TrackId'];
    transactionId = json['TransactionId'];
    paymentId = json['PaymentId'];
    authorizationId = json['AuthorizationId'];
    transactionStatus = json['TransactionStatus'];
    transationValue = json['TransationValue'];
    customerServiceCharge = json['CustomerServiceCharge'];
    dueValue = json['DueValue'];
    paidCurrency = json['PaidCurrency'];
    paidCurrencyValue = json['PaidCurrencyValue'];
    currency = json['Currency'];
    error = json['Error'];
    cardNumber = json['CardNumber'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['TransactionDate'] = this.transactionDate;
    data['PaymentGateway'] = this.paymentGateway;
    data['ReferenceId'] = this.referenceId;
    data['TrackId'] = this.trackId;
    data['TransactionId'] = this.transactionId;
    data['PaymentId'] = this.paymentId;
    data['AuthorizationId'] = this.authorizationId;
    data['TransactionStatus'] = this.transactionStatus;
    data['TransationValue'] = this.transationValue;
    data['CustomerServiceCharge'] = this.customerServiceCharge;
    data['DueValue'] = this.dueValue;
    data['PaidCurrency'] = this.paidCurrency;
    data['PaidCurrencyValue'] = this.paidCurrencyValue;
    data['Currency'] = this.currency;
    data['Error'] = this.error;
    data['CardNumber'] = this.cardNumber;
    return data;
  }
}
